Changed to add KL25Z.

Dependents:   ABBlind_hardware_test Tarea_Reloj_mayamira Nucleo_read_button_interrupt_copy SOS_V1

Fork of PinDetect by Andy K

Revision:
3:cb6051b90a52
Parent:
2:cb3afc45028b
--- a/PinDetect.h	Thu Jan 13 11:09:22 2011 +0000
+++ b/PinDetect.h	Fri May 16 07:27:14 2014 +0000
@@ -172,13 +172,13 @@
 
     /** PinDetect constructor
      *
      * By default the PinMode is set to PullDown.
      *
      * @see http://mbed.org/handbook/DigitalIn
      * @param p PinName is a valid pin that supports DigitalIn
      */    
     PinDetect(PinName p) {
-        init( p, PullDown );
+        init( p, PullDefault );
     }
 
     /** PinDetect constructor
@@ -172,13 +172,13 @@
     /** PinDetect constructor
      *
-     * By default the PinMode is set to PullDown.
+     * By default the PinMode is set to PullDefault.
      *
      * @see http://mbed.org/handbook/DigitalIn